import java.io.File;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Scanner;
import java.util.Set;

// Solution to the Boggle Me! problem from the 2019 FIU
// High School Programming Competition, lower division.
// by Kip Irvine, March 2019

public class Boggle {
	Set<String> mwords;
	int rows, cols;
	char[][] matrix;
	
	// Build a string from an array of characters.
	// Arrays.toString cannot be used because it inserts commas.
	String concat( char[] array ) {
		StringBuilder b = new StringBuilder();
		for( char ch : array)
			b.append(ch);
		return b.toString();
	}
	
	// make a set of all 4-letter words found in the grid.
	void createWordSet( ) {
		
		// for every row...
		for(int m=0; m < rows; m++) {
			// one row, left to right
			for(int i=0; i < cols-3; i++) {
				char[] word = new char[4];
				for(int j=i, k=0; k < 4 && j < cols; j++ ) {	
					word[k++] = matrix[m][j];
				}			
				String wordstr = concat(word); 
				mwords.add(wordstr);
			}  // for i
		} // m rows
		
		// for every column...
		for(int m=0; m < cols; m++) {
			// one column, top to bottom
			for(int i=0; i < rows-3; i++) {
				char[] word = new char[4];
				for(int j=i, k=0; k < 4 && j < rows; j++ ) {	
					word[k++] = matrix[j][m];
				}			
				String wordstr = concat(word); 
				mwords.add(wordstr);
			} // for i
		} // m rows

	}
	
	void printWordList() {
		System.out.print("[");
		for( String word: mwords) {
			System.out.printf("%s, ", word);
		}
		System.out.println("]");
	}
	
	
	void start() throws Exception {
		mwords = new HashSet<>();
		
		Scanner in = new Scanner(System.in);
		//Scanner in = new Scanner(new File("boggle.in.txt"));
		
		// save the list of words
		List<String> wordsToFind = new LinkedList<>();
		String[] line = in.nextLine().split(" ");
		for(String s : line)
			wordsToFind.add(s);
				
		// read the boggle grid
		rows = in.nextInt();
		cols = in.nextInt();
		in.nextLine();
		matrix = new char[rows][cols];
		
		for(int i=0; i < rows; i++) {
			matrix[i] = in.nextLine().toCharArray();		
		}
		
		createWordSet(  );  // create set of all words in the grid
		
		// Ask if every word in the list was in the set of words
		// found in the grid.
		String result = "YES";
		for( String word : wordsToFind ) {
			if( !mwords.contains(word)) {
				result = "NO";
				break;
			}
		}
		System.out.println(result);		
	}
	
	
	public static void main(String[] args) throws Exception {
		new Boggle().start();

	}

}
